@@ -12,7 +12,8 @@ module.exports = function(hg, done) {
 						if (res.notes) {
 							res.notes = JSON.parse(res.notes);
 						}
-						hg.event.emit('on' + res.action[0] + res.action.substr(1).toLowerCase() + res.table_name[0].toUpperCase() + res.table_name.substr(1), [client, res]);
+
+						hg.event.emit('on' + res.action[0].toUpperCase() + res.action.substr(1).toLowerCase() + res.table_name[0].toUpperCase() + res.table_name.substr(1).replace(/_(.)/g, function(_, letter) {  return letter.toUpperCase(); }), [client, res]);
 					});
 					client.query('TRUNCATE TABLE hg_update_queue');
 				});
@@ -63,7 +64,7 @@ module.exports = function(hg, done) {
 				if (err.code !== 'PROTOCOL_CONNECTION_LOST') {
 					throw err;
 				}
-	
+
 				hg.log('reconnecting mysql');
 				hg.save(hg.conf.hubgraph.root);
 				connect();
@@ -150,7 +151,7 @@ module.exports = function(hg, done) {
 			if (!cats[domain + '~' + val]) {
 				hg.add({'domain': 'domains', 'id': domain + '~' + val, 'title': domain + ' ' + val});
 				hg.connect('domain', 'meta', 'domains', 'domains', domain + '~' + val);
-				hg.connect('subdomain', 'domains', domain, 'domains', domain + '~' + val); 
+				hg.connect('subdomain', 'domains', domain, 'domains', domain + '~' + val);
 				cats[domain + '~' + val] = true;
 			}
 			hg.connect('domain', 'domains', domain + '~' + val, domain, res.id);
@@ -159,7 +160,7 @@ module.exports = function(hg, done) {
 				if (!cats[dm]) {
 					hg.add({'domain': 'domains', 'id': dm, 'title': dm});
 					hg.connect('domain', 'meta', 'domains', 'domains', dm);
-					hg.connect('subdomain', 'domains', domain, 'domains', dm); 
+					hg.connect('subdomain', 'domains', domain, 'domains', dm);
 					cats[domain + '~' + val] = true;
 				}
 				hg.connect('domain', 'domains', dm, domain, res.id);
@@ -168,6 +169,7 @@ module.exports = function(hg, done) {
 
 		if (res.contributor_ids) {
 			res.contributor_ids.forEach(function(cid) {
+				hg.connect('contributor', 'members', cid, domain, res.id);
 				hg.connect('alias', 'aliases', 'user:' + cid, domain, res.id);
 			});
 		}
