@@ -32,21 +32,26 @@ module.exports = function(hg) {
 		if (item.domain == 'members' && !item.public) {
 			return false;
 		}
-		if (item.domain == 'discussions' && item.group_ids && item.group_ids[0]) {
-			var gid = item.group_ids[0];
-			if (!hg.groupPerms[gid] || !hg.groupPerms[gid].params.forum) {
-				return false;
-			}
-			var perms = hg.groupPerms[gid].params.forum;
-			if (perms == 'nobody' || (perms == 'registered' && !args.uid) || (perms == 'members' && !args.groupMap[gid])) {
-				return false;
-			}
+
+		if (item.owner_only && args.uid != item.owner_only) {
+			return false;
 		}
 
 		if (item.access !== undefined && item.access > 0 && !args.uid) {
 			return false;
 		}
 
+		var groupParamDomainMap = {
+			'wikis'        : 'wiki',
+			'discussions'  : 'forum',
+			'blogs'        : 'blog',
+			'wishes'       : 'wishlist',
+			'resources'    : 'resources',
+			'events'       : 'calendar',
+			'announcements': 'announcements',
+			'collections'  : 'collections'
+		};
+
 		if (item.group_ids) {
 			var gid = item.group_ids.length ? item.group_ids[0] : item.group_ids;
 			if (gid && gid != '') {
@@ -57,8 +62,12 @@ module.exports = function(hg) {
 				if (hg.groupPerms[gid].privacy == 1 && !args.groupMap[gid]) {
 					return false;
 				}
-				if (hg.groupPerms[gid].discoverability == 1) {
-					return false;
+				var param = groupParamDomainMap[item.domain];
+				if (param) {
+					var perms = hg.groupPerms[gid].params[param];
+					if (!perms || perms == 'nobody' || (perms == 'registered' && !args.uid) || (perms == 'members' && !args.groupMap[gid])) {
+						return false;
+					}
 				}
 			}
 		}
@@ -141,7 +150,7 @@ module.exports = function(hg) {
 		return rv;
 	};
 
-	var parseTerms = function(str) {	
+	var parseTerms = function(str) {
 		var autoThresh = 500;
 		var suggThresh = 25;
 		var rv = {
@@ -197,7 +206,7 @@ module.exports = function(hg) {
 			if (idx < len - 1) {
 				--idx;
 			}
-			
+
 			var key = mand ? 'mandatory' : (neg ? 'negative' : 'positive');
 			var qids = [];
 			var quoted = quote && /\s/.test(term);
@@ -231,7 +240,7 @@ module.exports = function(hg) {
 				rv.text.push(term);
 				if (quote) {
 					term.split(/\s+/).forEach(function(t) {
-						t = hg.stem(t); 
+						t = hg.stem(t);
 						if (hg.isStopWord(t)) {
 							return;
 						}
@@ -276,7 +285,7 @@ module.exports = function(hg) {
 	};
 
 	// @TODO eliminating stop words from phrases messes them up:
-	// "horse to riding" -> /(horse[-\s]+riding)/gi
+	// "horse to ride" -> /(horse[-\s]+ride)/gi
 	var getTermRe = function(terms) {
 		return new RegExp('(' + terms.map(function(term) {
 			return reQuote(term.string.split(/[-\s]+/).filter(function(word) {
@@ -296,8 +305,8 @@ module.exports = function(hg) {
 			'after': 250,
 			'total': isChild ? 200 : 350
 		};
-		if (t.length < 50) {
-			return null;
+		if (t.length < 500) {
+			return t;
 		}
 
 		var isTerminatingCharacter = function(ch, terms) {
@@ -510,7 +519,7 @@ module.exports = function(hg) {
 				return count == umCount;
 			});
 		}
-		
+
 		if (args.inGroup && args.inGroup.length) {
 			var gm = {}, gmCount = 0;
 			args.inGroup.forEach(function(gid) {
@@ -539,11 +548,18 @@ module.exports = function(hg) {
 			return selectors.every(function(fun) { return fun(item, idx); })
 		};
 
-		if (args.domain && args.domain != 'all') {
-			selectors.push(function(item) {
-				return item.domain == args.domain;
-			});
-		}
+                if (args.domain && args.domain != 'all') {
+                        var domParts = args.domain.split('~');
+                        selectors.push(function(item) {
+                                if (item.domain !== domParts[0]) {
+                                        return false;
+                                }
+                                if (domParts[1] && item.type !== domParts[1]) {
+                                        return false;
+                                }
+                                return true;
+                        });
+                }
 
 		var now = new Date(),
 		    day = 1000 * 60 * 60 * 24,
@@ -556,7 +572,7 @@ module.exports = function(hg) {
 				if (!item.date) {
 					return false;
 				}
-				var dt = new Date(item.date); 
+				var dt = new Date(item.date);
 				if (/^\d+$/.test(args.timeframe)) {
 					return dt.getUTCFullYear() == args.timeframe;
 				}
@@ -582,17 +598,13 @@ module.exports = function(hg) {
 						.map(function(t) { return t.string })
 				)
 				.join(' ');
-			
+
 			termRe = getTermRe(terms.positive.concat(terms.mandatory));
-			
+
 			var textV = hg.selectText(text);
 			// title-word matches
 			rv.results.union(textV
 				.out('title-word')
-//					.use(['title'])
-//					.adjustWeights(function(item) {
-//						return textSimularity(item.title, text) + item.weight/2;
-//					})
 					.normalizeWeights()
 					.scaleWeights(baseWeight.titleWord),
 				false, // don't bother sorting yet
@@ -601,10 +613,6 @@ module.exports = function(hg) {
 			// body-word matches
 			rv.results.union(textV
 				.out('body-word')
-//					.use(['body'])
-//					.adjustWeights(function(item) {
-//						return textSimularity(item.body, text) + item.weight/4;
-//					})
 					.normalizeWeights()
 					.scaleWeights(baseWeight.bodyWord),
 				false, // don't bother sorting yet
@@ -621,6 +629,9 @@ module.exports = function(hg) {
 			if (args.inGroup.length) {
 				seeded = true;
 				rv.results = hg.select('aliases', 'group:' + args.inGroup[0]).out('alias');
+				validators.push(function(item) {
+					return item.domain == 'resources';
+				});
 			}
 			else if (args.domain.length) {
 				seeded = true;
@@ -721,12 +732,19 @@ module.exports = function(hg) {
 		// figure out metadata about the whole result set before we trim down to the current page
 		rv.results.items.forEach(function(item) {
 			if (item.domain == 'members') {
-				var count = 0;
-				for (var k in item.contributions) {
-					count += item.contributions[k];
-				}
-				item.count = count;
-				maxContributions = Math.max(maxContributions, count);
+				item.contributions = {};
+				item.count = 0;
+				hg.select('members', item.id).out('contributor').use().items.forEach(function(c) {
+					if (!hg.views.filterVisible(c, args)) {
+						return;
+					}
+					if (!item.contributions[c.domain]) {
+						item.contributions[c.domain] = 0;
+					}
+					++item.contributions[c.domain];
+					++item.count;
+				});
+				maxContributions = Math.max(item.count, maxContributions);
 			}
 			if (!rv.domains[item.domain]) {
 				rv.domains[item.domain] = 1;
@@ -735,7 +753,7 @@ module.exports = function(hg) {
 				++rv.domains[item.domain];
 			}
 		});
-		
+
 		rv.total = rv.results.items.length;
 
 		var anyTimes = false;
@@ -757,22 +775,6 @@ module.exports = function(hg) {
 						});
 					}
 				});
-				/*
-				var rels = {'tag': 'aliases', 'contributor': 'members', 'group': 'groups'};
-				for (var type in rels) {
-					var key = type + '_ids';
-					if (item[key]) {
-						item[key].forEach(function(id) {
-							if (!rv[type + 's'][id]) {
-								rv[type + 's'][id] = [hg.select(rels[type], type == 'tag' ? 'tag:' + id : id).use().items[0].title, 1];
-							}
-							else {
-								++rv[type + 's'][id][1];
-							}
-						});
-					}
-				}
-				*/
 
 				if (item.date) {
 					var dt = new Date(item.date),
@@ -788,7 +790,7 @@ module.exports = function(hg) {
 						++rv.timeframe[yr][1];
 					}
 					if (diff <= day) {
-						++rv.timeframe['day'][1];	
+						++rv.timeframe['day'][1];
 					}
 					else if (diff <= week) {
 						++rv.timeframe['week'][1];
@@ -801,7 +803,7 @@ module.exports = function(hg) {
 					}
 
 				}
-																																																		
+
 				if (item.domain == 'members') {
 					// bonus for being a contributor
 					if (maxContributions > 0) {
@@ -815,12 +817,12 @@ module.exports = function(hg) {
 		if (!anyTimes) {
 			rv.timeframe = [];
 		}
-		
+
 		// rv now contains a bunch of {id: [null, # of items in result]} entries for metadata
 		// we look them now to fill them in so they have {id: ['Nice Title', # of items]} instead
 		var facets = {'tag': 'tags', 'group': 'groups', 'user': 'contributors'};
 		for (var k in facets) {
-			// it's possible that some metadata items need to be included even though they were 
+			// it's possible that some metadata items need to be included even though they were
 			// responsible for no result items, when the user has selected them as a facet for
 			// a query that returns no results. they need to show up so that the client gives
 			// the user an opportunity to de-select the facet
@@ -840,7 +842,7 @@ module.exports = function(hg) {
 				}
 			}
 		}
-		
+
 		rv.results = rv.results
 			.sort()
 			.items;
@@ -848,7 +850,7 @@ module.exports = function(hg) {
 		setTimeout(function() {
 			delete cache[rv.cache];
 		}, 1000 * 60 * 10);
-		rv.results = rv.results 
+		rv.results = rv.results
 			.slice(rv.offset, rv.offset + 1*args.per)
 			.map(displayFormat(termRe));
 		return rv;
